@@ -30,7 +30,7 @@ void MimeTypeTest::testMimeTypeDetection_data()
     QTest::addColumn<QString>("expectedMimeType");
 
     const QString compressedGzipTarMime = QStringLiteral("application/x-compressed-tar");
-    const QString compressedBzip2TarMime = QStringLiteral("application/x-bzip-compressed-tar");
+    const QString compressedBzip2TarMime = QMimeDatabase().mimeTypeForFile(QStringLiteral("dummy.tar.bz2"), QMimeDatabase::MatchExtension).name();
     const QString compressedXzTarMime = QStringLiteral("application/x-xz-compressed-tar");
     const QString compressedLzmaTarMime = QStringLiteral("application/x-lzma-compressed-tar");
     const QString compressedZTarMime = QStringLiteral("application/x-tarz");
@@ -38,7 +38,7 @@ void MimeTypeTest::testMimeTypeDetection_data()
     const QString compressedLzopTarMime = QStringLiteral("application/x-tzo");
     const QString compressedLrzipTarMime = QStringLiteral("application/x-lrzip-compressed-tar");
     const QString compressedLz4TarMime = QStringLiteral("application/x-lz4-compressed-tar");
-    const QString isoMimeType = QStringLiteral("application/x-cd-image");
+    const QString isoMimeType = QMimeDatabase().mimeTypeForFile(QStringLiteral("dummy.iso"), QMimeDatabase::MatchExtension).name();
     const QString debMimeType = QMimeDatabase().mimeTypeForFile(QStringLiteral("dummy.deb"), QMimeDatabase::MatchExtension).name();
     const QString xarMimeType = QStringLiteral("application/x-xar");
     const QString appImageMimeType = QStringLiteral("application/x-iso9660-appimage");
