@@ -28,13 +28,13 @@ Query::Query()
 
 QVariant Query::response() const
 {
-    return m_data.value(QStringLiteral( "response" ));
+    return m_data.value(QStringLiteral("response"));
 }
 
 void Query::waitForResponse()
 {
     QMutexLocker locker(&m_responseMutex);
-    //if there is no response set yet, wait
+    // if there is no response set yet, wait
     if (!m_data.contains(QLatin1String("response"))) {
         m_responseCondition.wait(&m_responseMutex);
     }
@@ -42,13 +42,13 @@ void Query::waitForResponse()
 
 void Query::setResponse(const QVariant &response)
 {
-    m_data[QStringLiteral( "response" )] = response;
+    m_data[QStringLiteral("response")] = response;
     m_responseCondition.wakeAll();
 }
 
-OverwriteQuery::OverwriteQuery(const QString &filename) :
-        m_noRenameMode(false),
-        m_multiMode(true)
+OverwriteQuery::OverwriteQuery(const QString &filename)
+    : m_noRenameMode(false)
+    , m_multiMode(true)
 {
     m_data[QStringLiteral("filename")] = filename;
 }
@@ -70,12 +70,7 @@ void OverwriteQuery::execute()
     QUrl destUrl = QUrl::fromLocalFile(QDir::cleanPath(m_data.value(QStringLiteral("filename")).toString()));
     const QUrl sourceUrl = QUrl(QStringLiteral("ark://%1").arg(destUrl.fileName()));
 
-    QPointer<KIO::RenameDialog> dialog = new KIO::RenameDialog(
-        nullptr,
-        i18nc("@title:window", "File Already Exists"),
-        sourceUrl,
-        destUrl,
-        options);
+    QPointer<KIO::RenameDialog> dialog = new KIO::RenameDialog(nullptr, i18nc("@title:window", "File Already Exists"), sourceUrl, destUrl, options);
     dialog.data()->exec();
 
     m_data[QStringLiteral("newFilename")] = dialog.data()->newDestUrl().toDisplayString(QUrl::PreferLocalFile);
@@ -89,35 +84,35 @@ void OverwriteQuery::execute()
 
 bool OverwriteQuery::responseCancelled()
 {
-    return m_data.value(QStringLiteral( "response" )).toInt() == KIO::Result_Cancel;
+    return m_data.value(QStringLiteral("response")).toInt() == KIO::Result_Cancel;
 }
 bool OverwriteQuery::responseOverwriteAll()
 {
-    return m_data.value(QStringLiteral( "response" )).toInt() == KIO::Result_OverwriteAll;
+    return m_data.value(QStringLiteral("response")).toInt() == KIO::Result_OverwriteAll;
 }
 bool OverwriteQuery::responseOverwrite()
 {
-    return m_data.value(QStringLiteral( "response" )).toInt() == KIO::Result_Overwrite;
+    return m_data.value(QStringLiteral("response")).toInt() == KIO::Result_Overwrite;
 }
 
 bool OverwriteQuery::responseRename()
 {
-    return m_data.value(QStringLiteral( "response" )).toInt() == KIO::Result_Rename;
+    return m_data.value(QStringLiteral("response")).toInt() == KIO::Result_Rename;
 }
 
 bool OverwriteQuery::responseSkip()
 {
-    return m_data.value(QStringLiteral( "response" )).toInt() == KIO::Result_Skip;
+    return m_data.value(QStringLiteral("response")).toInt() == KIO::Result_Skip;
 }
 
 bool OverwriteQuery::responseAutoSkip()
 {
-    return m_data.value(QStringLiteral( "response" )).toInt() == KIO::Result_AutoSkip;
+    return m_data.value(QStringLiteral("response")).toInt() == KIO::Result_AutoSkip;
 }
 
 QString OverwriteQuery::newFilename()
 {
-    return m_data.value(QStringLiteral( "newFilename" )).toString();
+    return m_data.value(QStringLiteral("newFilename")).toString();
 }
 
 void OverwriteQuery::setNoRenameMode(bool enableNoRenameMode)
@@ -140,10 +135,10 @@ bool OverwriteQuery::multiMode()
     return m_multiMode;
 }
 
-PasswordNeededQuery::PasswordNeededQuery(const QString& archiveFilename, bool incorrectTryAgain)
+PasswordNeededQuery::PasswordNeededQuery(const QString &archiveFilename, bool incorrectTryAgain)
 {
-    m_data[QStringLiteral( "archiveFilename" )] = archiveFilename;
-    m_data[QStringLiteral( "incorrectTryAgain" )] = incorrectTryAgain;
+    m_data[QStringLiteral("archiveFilename")] = archiveFilename;
+    m_data[QStringLiteral("incorrectTryAgain")] = incorrectTryAgain;
 }
 
 void PasswordNeededQuery::execute()
@@ -159,22 +154,19 @@ void PasswordNeededQuery::execute()
     // Disabling Ok button on dialog open
     dlg.data()->buttonBox()->button(QDialogButtonBox::Ok)->setEnabled(false);
 
-    auto linePassword =
-        dlg.data()->findChild<KPasswordLineEdit *>(QStringLiteral("passEdit"));
+    auto linePassword = dlg.data()->findChild<KPasswordLineEdit *>(QStringLiteral("passEdit"));
 
     // If password is non empty, enable submit button
     QObject::connect(linePassword->lineEdit(), &QLineEdit::textChanged, linePassword->lineEdit(), [=] {
         if (linePassword->lineEdit()->text().isEmpty()) {
-            dlg.data()
-                ->buttonBox()
-                ->button(QDialogButtonBox::Ok)
-                ->setEnabled(false);
+            dlg.data()->buttonBox()->button(QDialogButtonBox::Ok)->setEnabled(false);
         } else {
             dlg.data()->buttonBox()->button(QDialogButtonBox::Ok)->setEnabled(true);
         }
     });
 
-    dlg.data()->setPrompt(xi18nc("@info", "The archive <filename>%1</filename> is password protected. Please enter the password.",
+    dlg.data()->setPrompt(xi18nc("@info",
+                                 "The archive <filename>%1</filename> is password protected. Please enter the password.",
                                  m_data.value(QStringLiteral("archiveFilename")).toString()));
 
     if (m_data.value(QStringLiteral("incorrectTryAgain")).toBool()) {
@@ -194,15 +186,15 @@ void PasswordNeededQuery::execute()
 
 QString PasswordNeededQuery::password()
 {
-    return m_data.value(QStringLiteral( "password" )).toString();
+    return m_data.value(QStringLiteral("password")).toString();
 }
 
 bool PasswordNeededQuery::responseCancelled()
 {
-    return !m_data.value(QStringLiteral( "response" )).toBool();
+    return !m_data.value(QStringLiteral("response")).toBool();
 }
 
-LoadCorruptQuery::LoadCorruptQuery(const QString& archiveFilename)
+LoadCorruptQuery::LoadCorruptQuery(const QString &archiveFilename)
 {
     m_data[QStringLiteral("archiveFilename")] = archiveFilename;
 }
@@ -227,7 +219,7 @@ bool LoadCorruptQuery::responseYes()
     return (m_data.value(QStringLiteral("response")).toInt() == KMessageBox::PrimaryAction);
 }
 
-ContinueExtractionQuery::ContinueExtractionQuery(const QString& error, const QString& archiveEntry)
+ContinueExtractionQuery::ContinueExtractionQuery(const QString &error, const QString &archiveEntry)
     : m_chkDontAskAgain(i18n("Don't ask again."))
 {
     m_data[QStringLiteral("error")] = error;
@@ -244,19 +236,22 @@ void ContinueExtractionQuery::execute()
                     xi18n("Extraction of the entry:<nl/>"
                           "    <filename>%1</filename><nl/>"
                           "failed with the error message:<nl/>    %2<nl/><nl/>"
-                          "Do you want to continue extraction?<nl/>", m_data.value(QStringLiteral("archiveEntry")).toString(),
+                          "Do you want to continue extraction?<nl/>",
+                          m_data.value(QStringLiteral("archiveEntry")).toString(),
                           m_data.value(QStringLiteral("error")).toString()),
-                    QMessageBox::Yes|QMessageBox::Cancel);
+                    QMessageBox::Yes | QMessageBox::Cancel);
     box.setCheckBox(&m_chkDontAskAgain);
     setResponse(box.exec());
     QApplication::restoreOverrideCursor();
 }
 
-bool ContinueExtractionQuery::responseCancelled() {
+bool ContinueExtractionQuery::responseCancelled()
+{
     return (m_data.value(QStringLiteral("response")).toInt() == QMessageBox::Cancel);
 }
 
-bool ContinueExtractionQuery::dontAskAgain() {
+bool ContinueExtractionQuery::dontAskAgain()
+{
     return m_chkDontAskAgain.isChecked();
 }
 
